about summary refs log tree commit diff
path: root/pkgs/build-support
diff options
context:
space:
mode:
authorBryan Lai <bryanlais@gmail.com>2024-01-07 18:47:47 +0800
committerBryan Lai <bryanlais@gmail.com>2024-01-08 19:42:16 +0800
commitdf62c3c87f35cd50d6ee20ea92900bb03ad827c9 (patch)
treef1d174b0787fff484f849b8fdc6e9a37ecfcaa44 /pkgs/build-support
parent9ff61712cb18bcd0ca1f1ec1b8cb1a75ad634263 (diff)
downloadnixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.tar
nixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.tar.gz
nixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.tar.bz2
nixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.tar.lz
nixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.tar.xz
nixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.tar.zst
nixlib-df62c3c87f35cd50d6ee20ea92900bb03ad827c9.zip
checkpointBuildTools: mkCheckpointedBuild -> mkCheckpointBuild
All other functions are in the form of `*{c,C}heckpointBuild*`, so we
deprecate the `mkCheckpointedBuild` function in favor of `mkCheckpointBuild`.

Also address some inconsistencies in the docs: some `buildOutput` should
actually be `incrementalBuildArtifacts`.
Diffstat (limited to 'pkgs/build-support')
-rw-r--r--pkgs/build-support/checkpoint-build.nix10
1 files changed, 7 insertions, 3 deletions
diff --git a/pkgs/build-support/checkpoint-build.nix b/pkgs/build-support/checkpoint-build.nix
index e08dde353e89..5876202b0bd0 100644
--- a/pkgs/build-support/checkpoint-build.nix
+++ b/pkgs/build-support/checkpoint-build.nix
@@ -14,7 +14,7 @@ rec {
     *   changedVBox = pkgs.virtuabox.overrideAttrs (old: {
     *      src = path/to/vbox/sources;
     *   }
-    * - use `mkCheckpointedBuild changedVBox buildOutput`
+    * - use `mkCheckpointBuild changedVBox incrementalBuildArtifacts`
     * - enjoy shorter build times
   */
   prepareCheckpointBuild = drv: drv.overrideAttrs (old: {
@@ -49,9 +49,9 @@ rec {
     * Usage:
     * let
     *   checkpointArtifacts = prepareCheckpointBuild drv
     * in mkCheckpointedBuild drv checkpointArtifacts
   */
-  mkCheckpointedBuild = drv: previousBuildArtifacts: drv.overrideAttrs (old: {
+  mkCheckpointBuild = drv: previousBuildArtifacts: drv.overrideAttrs (old: {
     # The actual checkpoint build phase.
     # We compare the changed sources from a previous build with the current and create a patch
     # Afterwards we clean the build directory to copy the previous output files (Including the sources)
@@ -66,4 +66,8 @@ rec {
       patch -p 1 -i sourceDifference.patch
     '';
   });
+
+  mkCheckpointedBuild = pkgs.lib.warn
+    "`mkCheckpointedBuild` is deprecated, use `mkCheckpointBuild` instead!"
+    mkCheckpointBuild;
 }
@@ -49,9 +49,9 @@ rec {
     * let
     *   checkpointArtifacts = prepareCheckpointBuild drv
-    * in mkCheckpointedBuild drv checkpointArtifacts
+    * in mkCheckpointBuild drv checkpointArtifacts
   */